# -*- encoding: utf-8 -*-
#
# Simple support for organizing bzr branches as complex project
#
# Copyright (C) 2008-2011 Alexander Belchenko <bialix AT ukr net>
# License: GNU GPL v.2

"""Organise and manage a collection of bzr branches as a complex project.

Here is a summary of the commands added.

====================    =======================================================
Command                 Description
====================    =======================================================
project-init            Initialize new project meta-directory
project-get             Get a copy of an existing project on your local disk
project-add             Add new component to the project
project-commit          Commit changes in components working copies
project-info            Show info summary for project
project-branch          Change origin of the component
project-update          Update components of the project from their origins
project-publish         Publish (push back) changes from components branches
                        and control branch
project-command         Run some command(s) for project components
====================    =======================================================

For tutorials, developer documentation and comparisons with other systems,
see http://bialix.com/scmproj/docs/.
"""

version_info = (0, 6, 2, 'final', 0)

from bzrlib.commands import plugin_cmds
from bzrlib import ignores


ignores.add_runtime_ignores(['./.bzrmeta/scmproj/local'])

lazy_commands = (
    # (name, aliases, module)
    ('cmd_project_add',      ['padd'],  'bzrlib.plugins.scmproj.cli'),
    ('cmd_project_branch',   ['pbranch'],
                                        'bzrlib.plugins.scmproj.cli'),
    ('cmd_project_commit',   ['pci', 'pcommit'],
                                        'bzrlib.plugins.scmproj.cli'),
    ('cmd_project_get',      ['pget'],  'bzrlib.plugins.scmproj.cli'),
    ('cmd_project_info',     ['pinfo'], 'bzrlib.plugins.scmproj.cli'),
    ('cmd_project_init',     ['pinit'], 'bzrlib.plugins.scmproj.cli'),
    ('cmd_project_publish',  ['pback', 'project-push', 'ppush'],
                                        'bzrlib.plugins.scmproj.cli'),
    ('cmd_project_update',   ['pup', 'pupdate'],
                                        'bzrlib.plugins.scmproj.cli'),

    ('cmd_project_command',  ['pcmd', 'prun', 'pcommand'],
                                        'bzrlib.plugins.scmproj.cli'),
    # hidden
    ('cmd_chdir',            ['cd'],    'bzrlib.plugins.scmproj.cli'),
    # debug
    ('cmd_dump_ptree',       [],        'bzrlib.plugins.scmproj.cli'),
)

for name, aliases, module in lazy_commands:
    plugin_cmds.register_lazy(name, aliases, module)


def test_suite():
    from bzrlib.plugins.scmproj import tests
    return tests.test_suite()
