# Simple support for organizing bzr branches as complex project
#
# Copyright (C) 2008, 2009 Alexander Belchenko <bialix AT ukr net>
# License: GNU GPL v.2

import os

from bzrlib import (
    commands,
    urlutils,
    )
from bzrlib.tests import TestCaseWithTransport
from bzrlib.tests.test_sftp_transport import TestCaseWithSFTPServer
from bzrlib.transport import get_transport

from bzrlib.plugins.scmproj import (
    project,
    )


INSTALL_CMD = getattr(commands, "install_bzr_command_hooks", lambda: None)


class TestChdir(TestCaseWithTransport):

    def test_chdir_cwd(self):
        # I'm not paranoid just curious
        orig_cwd = os.getcwdu()
        os.chdir('.')
        os.chdir(orig_cwd)


class TestCli(TestCaseWithTransport):

    def setUp(self):
        TestCaseWithTransport.setUp(self)
        INSTALL_CMD()

    def test_project_init_v2(self):
        # pinit creates only v2 projects.
        # there is no way to create v1, and this is a deliberate decision.
        # ----------------------------------------------------------------
        # pinit in the current directory
        stdout, stderr = self.run_bzr('project-init .')
        self.assertContainsRe(stdout,
            r'New top-level branch intialized in current directory.')
        self.assertIsDirectory('.bzr', get_transport('.'))
        self.assertIsDirectory('.bzrmeta/scmproj', get_transport('.'))
        # pinit in the other directory
        stdout, stderr = self.run_bzr('pinit a')
        self.assertContainsRe(stdout,
            r'New top-level branch intialized in "a".')
        self.assertIsDirectory('.bzr', get_transport('a'))
        self.assertIsDirectory('.bzrmeta/scmproj', get_transport('a'))

    def test_project_get_v1(self):
        self.build_tree(['x/'])
        project.Project.initialize('x/a', _scmproj_format='v1')

        # derived project dir name
        out, err = self.run_bzr('project-get x/a')
        self.assertIsDirectory('.scmproj', get_transport('a'))

        # explicit project dir name
        out, err = self.run_bzr('pget x/a b')
        self.assertIsDirectory('.scmproj', get_transport('b'))


class TestCliRemote(TestCaseWithSFTPServer):

    def test_project_init(self):
        return # this test failed because of Bug #526221
        remote_url = self.get_url()
        stdout, stderr = self.run_bzr(['pinit', remote_url])
        self.assertContainsRe(stdout,
            r'New scmproj control branch intialized at "%s".' % remote_url)
        self.assertIsDirectory('.bzr', self.get_transport('.'))

    def test_project_get(self):
        return # this test failed because of Bug #526221
        remote_url = self.get_url('a')
        stdout, stderr = self.run_bzr(['pinit', remote_url])
        self.assertIsDirectory('.bzr', self.get_transport('a'))

        # derived project dir name
        out, err = self.run_bzr(['project-get', remote_url])
        self.assertIsDirectory('.scmproj', get_transport('a'))

        # explicit project dir name
        out, err = self.run_bzr(['project-get', remote_url, 'b'])
        self.assertIsDirectory('.scmproj', get_transport('b'))
