# Simple support for organizing bzr branches as complex project
#
# Copyright (C) 2008, 2009 Alexander Belchenko <bialix AT ukr net>
# License: GNU GPL v.2

from bzrlib.tests import TestCase
from bzrlib.plugins.scmproj.config import IndexCard
from bzrlib.plugins.scmproj.tests.whiteutils import reindentBlock


class TestIndexCard(TestCase):

    def test_default(self):
        ic = IndexCard()
        self.assertEquals(reindentBlock("""\
            # index card v2
            """), ic.to_str())
        self.assertEqual(None, ic.get_component('foo'))
        self.assertEqual(None, ic.get_component('bar'))

    def test_set_data(self):
        ic = IndexCard()
        ic.set_component('foo', 'my-foo-revid')
        ic.set_component('bar', 'my-bar-revidd')
        self.assertEquals(reindentBlock("""\
            # index card v2
            foo = my-foo-revid
            bar = my-bar-revidd
            """), ic.to_str())

    def test_get_data(self):
        ic = IndexCard(reindentBlock("""\
            # index card v2
            bar = my-bar-revidd
            foo = my-foo-revid
            """))
        self.assertEqual('my-foo-revid', ic.get_component('foo'))
        self.assertEqual('my-bar-revidd', ic.get_component('bar'))
        self.assertEqual(None, ic.get_component('spam'))
        self.assertEqual('revid:my-foo-revid', ic.get_revision('foo'))
        self.assertEqual('revid:my-bar-revidd', ic.get_revision('bar'))
        self.assertEqual(None, ic.get_revision('spam'))
        self.assertTrue(isinstance(ic.get_revid('foo'), str))
        self.assertTrue(isinstance(ic.get_revid('bar'), str))

    def test_update_revids_for_empty(self):
        ic = IndexCard()
        self.assertFalse(ic.update_revids(None))
        self.assertFalse(ic.update_revids({}))
        self.assertEquals(reindentBlock("""\
            # index card v2
            """), ic.to_str())
        #
        self.assertTrue(ic.update_revids({
            'foo': 'my-foo-revid',
            'bar': 'my-bar-revidd',
            }))
        self.assertEquals(reindentBlock("""\
            # index card v2
            bar = my-bar-revidd
            foo = my-foo-revid
            """), ic.to_str())

    def test_update_revids_for_nonempty(self):
        ic = IndexCard(reindentBlock("""\
            # index card v2
            foo = my-foo-revid
            bar = my-bar-revidd
            """))
        self.assertFalse(ic.update_revids(None))
        self.assertFalse(ic.update_revids({}))
        self.assertEquals(reindentBlock("""\
            # index card v2
            foo = my-foo-revid
            bar = my-bar-revidd
            """), ic.to_str())
        #
        self.assertTrue(ic.update_revids({
            'foo': 'new-foo-revid',
            'bar': 'my-bar-revidd',
            }))
        self.assertEquals(reindentBlock("""\
            # index card v2
            bar = my-bar-revidd
            foo = new-foo-revid
            """), ic.to_str())
