# Simple support for organizing bzr branches as complex project
#
# Copyright (C) 2008, 2009 Alexander Belchenko <bialix AT ukr net>
# License: GNU GPL v.2

from bzrlib import commands
from bzrlib.tests import TestCaseWithTransport

from bzrlib.plugins.scmproj import (
    vcs,
    )

INSTALL_CMD = getattr(commands, "install_bzr_command_hooks", lambda: None)


class TestBzrVcs(TestCaseWithTransport):

    def setUp(self):
        super(TestBzrVcs, self).setUp()
        INSTALL_CMD()
        self.vo = vcs.BzrVcs()

    def test_is_shared_repo(self):
        self.assertFalse(self.vo.is_shared_repo('.'))
        self.run_bzr(['init-repo', '.'])
        self.assertTrue(self.vo.is_shared_repo('.'))

    def test_create_repo(self):
        self.vo.create_repo('.')
        self.assertTrue(self.vo.is_shared_repo('.'))

    def test_is_branch(self):
        self.assertFalse(self.vo.is_branch('.'))
        self.run_bzr(['init', '.'])
        self.assertTrue(self.vo.is_branch('.'))
        
    def test_create_branch(self):
        self.vo.create_branch('.')
        self.assertTrue(self.vo.is_branch('.'))

    def test_is_checkout(self):
        self.assertFalse(self.vo.is_checkout('.'))
        self.run_bzr('init')
        self.assertTrue(self.vo.is_checkout('.'))
        self.run_bzr('remove-tree')
        self.assertFalse(self.vo.is_checkout('.'))

    def test_is_tree_changed(self):
        wt = self.make_branch_and_tree('branch')
        self.build_tree(['branch/dir/', 'branch/file'])
        wt.add(['dir', 'file'])
        wt.commit('initial')
        self.run_bzr(['checkout', '--lightweight', 'branch', 'light'])
        self.assertFalse(self.vo.is_tree_changed('light'))
        self.build_tree_contents([
            ('light/file', 'content had changed.'),
            ])
        self.assertTrue(self.vo.is_tree_changed('light'))
